summaryrefslogtreecommitdiff
path: root/opencl/source/opencl_device.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'opencl/source/opencl_device.cxx')
-rw-r--r--opencl/source/opencl_device.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/opencl/source/opencl_device.cxx b/opencl/source/opencl_device.cxx
index 1b6800e0ef8c..971c63ee3fe0 100644
--- a/opencl/source/opencl_device.cxx
+++ b/opencl/source/opencl_device.cxx
@@ -345,7 +345,7 @@ int pickBestDevice(std::unique_ptr<ds_profile> const & profile)
{
ds_device& device = profile->devices[d];
- // Check blacklist and whitelist for actual devices
+ // Check denylist and whitelist for actual devices
if (device.eType == DeviceType::OpenCLDevice)
{
// There is a silly impedance mismatch here. Why do we
@@ -360,10 +360,10 @@ int pickBestDevice(std::unique_ptr<ds_profile> const & profile)
aDevice.maName = OStringToOUString(device.sDeviceName, RTL_TEXTENCODING_UTF8);
aDevice.maDriver = OStringToOUString(device.sDriverVersion, RTL_TEXTENCODING_UTF8);
// If blacklisted or not whitelisted, ignore it
if (OpenCLConfig::get().checkImplementation(aPlatform, aDevice))
{
- SAL_INFO("opencl.device", "Device[" << d << "] " << device.sDeviceName << " is blacklisted or not whitelisted");
+ SAL_INFO("opencl.device", "Device[" << d << "] " << device.sDeviceName << " is denylisted or not whitelisted");
device.fTime = DBL_MAX;
device.bErrors = false;
}
@@ -360,10 +360,10 @@ int pickBestDevice(std::unique_ptr<ds_profile> const & profile)
aDevice.maName = OStringToOUString(device.sDeviceName, RTL_TEXTENCODING_UTF8);
aDevice.maDriver = OStringToOUString(device.sDriverVersion, RTL_TEXTENCODING_UTF8);
- // If blacklisted or not whitelisted, ignore it
+ // If denylisted or not whitelisted, ignore it
if (OpenCLConfig::get().checkImplementation(aPlatform, aDevice))
{